@@ -1,5 +1,5 @@
 lag1.plot <-
-function(series,max.lag=1,corr=TRUE,smooth=TRUE,col=gray(.1)){ 
+function(series,max.lag=1,corr=TRUE,smooth=TRUE,col=gray(.1), ...){ 
    #
    as.ts = stats::as.ts
    par = graphics::par
@@ -18,7 +18,7 @@ function(series,max.lag=1,corr=TRUE,smooth=TRUE,col=gray(.1)){
    old.par <- par(no.readonly = TRUE)
    par(mfrow=c(prow,pcol), mar=c(2.5, 2.5, 1, 1), mgp=c(1.6,.6,0), cex.main=1, font.main=1)
   for(h in 1:max.lag){                       
-   plot(stats::lag(series,-h), series, xy.labels=FALSE, main=paste(name1,h,")",sep=""), ylab=name2, xlab="", col=col, panel.first=Grid()) 
+   plot(stats::lag(series,-h), series, xy.labels=FALSE, main=paste(name1,h,")",sep=""), ylab=name2, xlab="", col=col, panel.first=Grid(), ...) 
     if (smooth==TRUE) 
     lines(stats::lowess(ts.intersect(stats::lag(series,-h),series)[,1],
                  ts.intersect(stats::lag(series,-h),series)[,2]), col="red")
